==> jc-1.4.0.tar.gz: polyglot/lex/Token.h <==
// public abstract class polyglot.lex.Token

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_lex_Token_H_
#define _JC_polyglot_lex_Token_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_runtime_Symbol$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Token$sub_refs	_jc_polyglot_lex_Token$sub_refs;
typedef struct _jc_polyglot_lex_Token$sub_nonrefs	_jc_polyglot_lex_Token$sub_nonrefs;
typedef struct _jc_polyglot_lex_Token$refs	_jc_polyglot_lex_Token$refs;
typedef struct _jc_polyglot_lex_Token$nonrefs	_jc_polyglot_lex_Token$nonrefs;
typedef struct _jc_polyglot_lex_Token$object	_jc_polyglot_lex_Token$object;

typedef const struct _jc_polyglot_lex_Token$vmethods	_jc_polyglot_lex_Token$vmethods;
typedef const struct _jc_polyglot_lex_Token$vtable	_jc_polyglot_lex_Token$vtable;
typedef const struct _jc_polyglot_lex_Token$vtype	_jc_polyglot_lex_Token$vtype;

// Constructors
extern void _jc_polyglot_lex_Token$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_Token$object *, struct _jc_polyglot_util_Position$object *, jint);

// Virtual methods
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_lex_Token$method$getPosition$93950f582a09a82d(_jc_env *, struct _jc_polyglot_lex_Token$object *);
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_polyglot_lex_Token$method$symbol$4d0189d5e9737af4(_jc_env *, struct _jc_polyglot_lex_Token$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_Token$method_info$getPosition$93950f582a09a82d;
extern _jc_method _jc_polyglot_lex_Token$method_info$symbol$4d0189d5e9737af4;

// Static methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_Token$method$escape$659645e54de5c36d(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_polyglot_lex_Token$vmethods {
	struct _jc_polyglot_util_Position$object	*(*getPosition$93950f582a09a82d)(_jc_env *, struct _jc_polyglot_lex_Token$object *);
	struct _jc_java__5fcup_runtime_Symbol$object	*(*symbol$4d0189d5e9737af4)(_jc_env *, struct _jc_polyglot_lex_Token$object *);
};

// Vtable
struct _jc_polyglot_lex_Token$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
};

// Vtype
struct _jc_polyglot_lex_Token$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Token$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Token$sub_refs {
	struct _jc_polyglot_util_Position$object	*position;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Token$refs {
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Token$sub_nonrefs {
	jint	symbol;
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Token$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
};

// Object instance structure
struct _jc_polyglot_lex_Token$object {
	_jc_polyglot_lex_Token$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Token$vtype	*vtype;
	_jc_polyglot_lex_Token$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Token$vtype _jc_polyglot_lex_Token$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Token, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Token$class_object;

#endif	/* _JC_polyglot_lex_Token_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/Token.h <==
// public abstract class polyglot.lex.Token

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_lex_Token_H_
#define _JC_polyglot_lex_Token_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_runtime_Symbol$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_Token$sub_refs	_jc_polyglot_lex_Token$sub_refs;
typedef struct _jc_polyglot_lex_Token$sub_nonrefs	_jc_polyglot_lex_Token$sub_nonrefs;
typedef struct _jc_polyglot_lex_Token$refs	_jc_polyglot_lex_Token$refs;
typedef struct _jc_polyglot_lex_Token$nonrefs	_jc_polyglot_lex_Token$nonrefs;
typedef struct _jc_polyglot_lex_Token$object	_jc_polyglot_lex_Token$object;

typedef const struct _jc_polyglot_lex_Token$vmethods	_jc_polyglot_lex_Token$vmethods;
typedef const struct _jc_polyglot_lex_Token$vtable	_jc_polyglot_lex_Token$vtable;
typedef const struct _jc_polyglot_lex_Token$vtype	_jc_polyglot_lex_Token$vtype;

// Constructors
extern void _jc_polyglot_lex_Token$method$_init$17774dfe64b6222d(_jc_env *, struct _jc_polyglot_lex_Token$object *, struct _jc_polyglot_util_Position$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_util_Position$object *_jc_polyglot_lex_Token$method$getPosition$93950f582a09a82d(_jc_env *, struct _jc_polyglot_lex_Token$object *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_runtime_Symbol$object *_jc_polyglot_lex_Token$method$symbol$4d0189d5e9737af4(_jc_env *, struct _jc_polyglot_lex_Token$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_Token$method_info$getPosition$93950f582a09a82d;
extern _jc_method _jc_polyglot_lex_Token$method_info$symbol$4d0189d5e9737af4;

// Static methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_Token$method$escape$659645e54de5c36d(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_lex_Token$vmethods {
	struct _jc_polyglot_util_Position$object	*(*getPosition$93950f582a09a82d)(_jc_env *, struct _jc_polyglot_lex_Token$object *) _JC_JCNI_ATTR;
	struct _jc_java__5fcup_runtime_Symbol$object	*(*symbol$4d0189d5e9737af4)(_jc_env *, struct _jc_polyglot_lex_Token$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_Token$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
};

// Vtype
struct _jc_polyglot_lex_Token$vtype {
	_jc_type			type;
	_jc_polyglot_lex_Token$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_Token$sub_refs {
	struct _jc_polyglot_util_Position$object	*position;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_Token$refs {
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_Token$sub_nonrefs {
	jint	symbol;
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_Token$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
};

// Object instance structure
struct _jc_polyglot_lex_Token$object {
	_jc_polyglot_lex_Token$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_Token$vtype	*vtype;
	_jc_polyglot_lex_Token$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_Token$vtype _jc_polyglot_lex_Token$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_Token, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_Token$class_object;

#endif	/* _JC_polyglot_lex_Token_H_ */
